/*
 * Copyright (C) 2024, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: iaom <zhangmengfei@kylinos.cn>
 *
 */

import QtQuick 2.12
import QtQuick.Layouts 1.12

import org.ukui.quick.widgets 1.0
import org.ukui.quick.items 1.0
import org.ukui.quick.platform 1.0

WidgetItem {
    id: root
    property bool isHorizontal: Widget.orientation == Types.Horizontal

    Layout.fillWidth: !isHorizontal
    Layout.fillHeight: isHorizontal
    Layout.preferredWidth: isHorizontal ? height : width
    Layout.preferredHeight: isHorizontal ? height : width

    //  更新tooltip
    Widget.tooltip: Widget.tooltip
    MouseArea {
        anchors.fill: parent
        hoverEnabled: true

        StyleBackground {
            anchors.fill: parent
            radius: Theme.normalRadius
            useStyleTransparency: false
            paletteRole: Theme.WindowText
            alpha: parent.containsPress ? 0.16 : parent.containsMouse ? 0.08 : 0
            Tooltip {
                id: tooltip
                anchors.fill: parent
                mainText: Widget.tooltip
                posFollowCursor: false
                location: {
                    switch(Widget.container.position) {
                        case Types.Bottom:
                            return Dialog.BottomEdge;
                        case Types.Left:
                            return Dialog.LeftEdge;
                        case Types.Top:
                            return Dialog.TopEdge;
                        case Types.Right:
                            return Dialog.RightEdge;
                    }
                }
                margin: 6
            }
        }

        Icon {
            anchors.centerIn: parent
            width: parent.height - 8
            height: parent.height - 8

            source: Widget.icon
            scale: parent.containsPress ? 0.95 : 1.0
        }

        onClicked: {
            AppLauncher.runCommand("ukui-intelligent-data-manager -s");
        }
    }
}
